@@ -71,7 +71,7 @@ def pointInTri2D(v, v1, v2, v3):
 
         mtx = Matrix((side1, side2, nor))
 
-        # Zero area 2d tri, even tho we throw away zerop area faces
+        # Zero area 2d tri, even tho we throw away zero area faces
         # the projection UV can result in a zero area UV.
         if not mtx.determinant():
             dict_matrix[key] = None
@@ -107,7 +107,6 @@ def boundsEdgeLoop(edges):
     # print len(faces), minx, maxx, miny , maxy
     for ed in edges:
         for pt in ed:
-            print 'ass'
             x= pt[0]
             y= pt[1]
             if x<minx: x= minx
@@ -162,7 +161,7 @@ def island2Edge(island):
     return length_sorted_edges, [v.to_3d() for v in unique_points.values()]
 
 # ========================= NOT WORKING????
-# Find if a points inside an edge loop, un-ordered.
+# Find if a points inside an edge loop, unordered.
 # pt is and x/y
 # edges are a non ordered loop of edges.
 # offsets are the edge x and y offset.
@@ -212,8 +211,11 @@ def islandIntersectUvIsland(source, target, SourceOffset):
     # Edge intersect test
     for ed in edgeLoopsSource:
         for seg in edgeLoopsTarget:
-            i = geometry.intersect_line_line_2d(\
-            seg[0], seg[1], SourceOffset+ed[0], SourceOffset+ed[1])
+            i = geometry.intersect_line_line_2d(seg[0],
+                                                seg[1],
+                                                SourceOffset+ed[0],
+                                                SourceOffset+ed[1],
+                                                )
             if i:
                 return 1 # LINE INTERSECTION
 
@@ -490,7 +492,7 @@ def mergeUvIslands(islandList):
                                 pass
 
                             if Intersect == 2:  # Source inside target
-                                '''
+                                """
                                 We have an intersection, if we are inside the target
                                 then move us 1 whole width across,
                                 Its possible this is a bad idea since 2 skinny Angular faces
@@ -498,8 +500,7 @@ def mergeUvIslands(islandList):
                                 since we have already tested for it.
 
                                 It gives about 10% speedup with minimal errors.
-                                '''
-                                #print 'ass'
+                                """
                                 # Move the test along its width + SMALL_NUM
                                 #boxLeft += sourceIsland[4] + SMALL_NUM
                                 boxLeft += sourceIsland[4]
@@ -693,11 +694,11 @@ def packIslands(islandList):
             islandIdx -=1
             continue
 
-        '''Save the offset to be applied later,
+        """Save the offset to be applied later,
         we could apply to the UVs now and allign them to the bottom left hand area
         of the UV coords like the box packer imagines they are
         but, its quicker just to remember their offset and
-        apply the packing and offset in 1 pass '''
+        apply the packing and offset in 1 pass """
         islandOffsetList.append((minx, miny))
 
         # Add to boxList. use the island idx for the BOX id.
@@ -708,7 +709,7 @@ def packIslands(islandList):
     # with the islands.
 
     #print '\tPacking UV Islands...'
-#XXX	Window.DrawProgressBar(0.7, 'Packing %i UV Islands...' % len(packBoxes) )
+#XXX	Window.DrawProgressBar(0.7, "Packing %i UV Islands..." % len(packBoxes) )
 
     # time1 = time.time()
     packWidth, packHeight = geometry.box_pack_2d(packBoxes)
@@ -719,7 +720,7 @@ def packIslands(islandList):
     #	raise "Error packed boxes differs from original length"
 
     #print '\tWriting Packed Data to faces'
-#XXX	Window.DrawProgressBar(0.8, 'Writing Packed Data to faces')
+#XXX	Window.DrawProgressBar(0.8, "Writing Packed Data to faces")
 
     # Sort by ID, so there in sync again
     islandIdx = len(islandList)
@@ -753,13 +754,10 @@ def VectoQuat(vec):
 
 
 class thickface(object):
-    __slost__= 'v', 'uv', 'no', 'area', 'edge_keys'
-    def __init__(self, face, uvface, mesh_verts):
+    __slost__= "v", "uv", "no", "area", "edge_keys"
+    def __init__(self, face, uv_layer, mesh_verts):
         self.v = [mesh_verts[i] for i in face.vertices]
-        if len(self.v)==4:
-            self.uv = uvface.uv1, uvface.uv2, uvface.uv3, uvface.uv4
-        else:
-            self.uv = uvface.uv1, uvface.uv2, uvface.uv3
+        self.uv = [uv_layer[i].uv for i in face.loop_indices]
 
         self.no = face.normal
         self.area = face.area
@@ -773,15 +771,16 @@ def main_consts():
     global ROTMAT_2D_POS_45D
     global RotMatStepRotation
 
-    ROTMAT_2D_POS_90D = Matrix.Rotation( radians(90.0), 2)
-    ROTMAT_2D_POS_45D = Matrix.Rotation( radians(45.0), 2)
+    ROTMAT_2D_POS_90D = Matrix.Rotation(radians(90.0), 2)
+    ROTMAT_2D_POS_45D = Matrix.Rotation(radians(45.0), 2)
 
     RotMatStepRotation = []
     rot_angle = 22.5 #45.0/2
     while rot_angle > 0.1:
-        RotMatStepRotation.append([\
-         Matrix.Rotation( radians(rot_angle), 2),\
-         Matrix.Rotation( radians(-rot_angle), 2)])
+        RotMatStepRotation.append([
+            Matrix.Rotation(radians(+rot_angle), 2),
+            Matrix.Rotation(radians(-rot_angle), 2),
+            ])
 
         rot_angle = rot_angle/2.0
 
@@ -831,7 +830,7 @@ def main(context,
         USER_ONLY_SELECTED_FACES = False
 
     if not obList:
-        raise('error, no selected mesh objects')
+        raise Exception("error, no selected mesh objects")
 
     # Reuse variable
     if len(obList) == 1:
@@ -888,13 +887,13 @@ def main(context,
         if not me.uv_textures: # Mesh has no UV Coords, don't bother.
             me.uv_textures.new()
 
-        uv_layer = me.uv_textures.active.data
+        uv_layer = me.uv_layers.active.data
         me_verts = list(me.vertices)
 
         if USER_ONLY_SELECTED_FACES:
-            meshFaces = [thickface(f, uv_layer[i], me_verts) for i, f in enumerate(me.faces) if f.select]
+            meshFaces = [thickface(f, uv_layer, me_verts) for i, f in enumerate(me.polygons) if f.select]
         else:
-        	meshFaces = [thickface(f, uv_layer[i], me_verts) for i, f in enumerate(me.faces)]
+            meshFaces = [thickface(f, uv_layer, me_verts) for i, f in enumerate(me.polygons)]
 
         if not meshFaces:
             continue
@@ -1105,15 +1104,16 @@ from bpy.props import FloatProperty
 
 
 class SmartProject(Operator):
-    '''This script projection unwraps the selected faces of a mesh. ''' \
-    '''it operates on all selected mesh objects, and can be used unwrap selected faces, or all faces'''
+    """This script projection unwraps the selected faces of a mesh """ \
+    """(it operates on all selected mesh objects, and can be used """ \
+    """to unwrap selected faces, or all faces)"""
     bl_idname = "uv.smart_project"
     bl_label = "Smart UV Project"
     bl_options = {'REGISTER', 'UNDO'}
 
     angle_limit = FloatProperty(
             name="Angle Limit",
-            description="lower for more projection groups, higher for less distortion",
+            description="Lower for more projection groups, higher for less distortion",
             min=1.0, max=89.0,
             default=66.0,
             )
